import "./chunk-YSQDPG26.js";

// src/lowlight.ts
import { Decoration } from "prosemirror-view";
function createParser(lowlight) {
  return function highlighter({ content, language, pos }) {
    const root = language ? lowlight.highlight(language, content) : lowlight.highlightAuto(content);
    const decorations = [];
    const from = pos + 1;
    fillFromRoot(decorations, root, from);
    return decorations;
  };
}
function fillFromRoot(decorations, node, from) {
  for (const child of node.children) {
    from = fillFromRootContent(decorations, child, from);
  }
}
function fillFromRootContent(decorations, node, from) {
  if (node.type === "element") {
    const to = from + getElementSize(node);
    const { className, ...rest } = node.properties;
    decorations.push(
      Decoration.inline(from, to, {
        class: className ? Array.isArray(className) ? className.join(" ") : String(className) : void 0,
        ...rest,
        nodeName: node.tagName
      })
    );
    return to;
  } else if (node.type === "text") {
    return from + node.value.length;
  } else {
    return from;
  }
}
function getElementSize(node) {
  let size = 0;
  for (const child of node.children) {
    size += getElementContentSize(child);
  }
  return size;
}
function getElementContentSize(node) {
  switch (node.type) {
    case "element":
      return getElementSize(node);
    case "text":
      return node.value.length;
    default:
      return 0;
  }
}
export {
  createParser
};
